import request from '@/utils/request'

// 查询退费申请列表
export function listTuifeisq(query) {
  return request({
    url: '/jxjy/Tuifeisq/list',
    method: 'get',
    params: query
  })
}

// 查询退费申请详细
export function getTuifeisq(id) {
  return request({
    url: '/jxjy/Tuifeisq/' + id,
    method: 'get'
  })
}

// 新增退费申请
export function addTuifeisq(data) {
  return request({
    url: '/jxjy/Tuifeisq',
    method: 'post',
    data: data
  })
}

// 修改退费申请
export function updateTuifeisq(data) {
  return request({
    url: '/jxjy/Tuifeisq',
    method: 'put',
    data: data
  })
}

// 删除退费申请
export function delTuifeisq(id) {
  return request({
    url: '/jxjy/Tuifeisq/' + id,
    method: 'delete'
  })
}



//协会退费
export function xiehuiTuifei(data){
	return request({
		url:"/jxjy/Tuifeisq/refundReview",
		data:data,
		method:"post"
	})
}
